@@ -1,41 +1,14 @@
 from datetime import datetime
 import time
 
-from django.test import LiveServerTestCase
+from base import BaseLiveServerTestCase
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.firefox.webdriver import WebDriver
 from selenium.common.exceptions import NoSuchElementException
 
 
-class ScriptTestCase(LiveServerTestCase):
-    def setUp(self):
-        self.browser = WebDriver()
-        self.do_admin_login('test', 'test')
-
-    def tearDown(self):
-        self.browser.quit()
-
-    def do_admin_login(self, username, password):
-        self.browser.get('%s%s' % (self.live_server_url, '/admin/'))
-        username_input = self.browser.find_element_by_name("username")
-        username_input.send_keys(username)
-        password_input = self.browser.find_element_by_name("password")
-        password_input.send_keys(password)
-        self.browser.find_element_by_xpath('//input[@value="Log in"]').click()
-
-    def new_window(self, name='other'):
-        self.browser.execute_script('window.open("/admin/", "'+ name +'")')
-        self.browser.switch_to_window(self.browser.window_handles[1])
-        while self.warning_element() is False:
-            time.sleep(0.1)
-        self.browser.switch_to_window(self.browser.window_handles[0])
-
-    def press_space(self):
-        a = ActionChains(self.browser)
-        a.key_down(Keys.SPACE)
-        a.perform()
-
+class ScriptTestCase(BaseLiveServerTestCase):
     def warning_element(self):
         try:
             return self.browser.find_elements_by_css_selector(
@@ -43,11 +16,6 @@ class ScriptTestCase(LiveServerTestCase):
         except IndexError:
             return False
 
-    def wait_for_pages_loaded(self):
-        for win in self.browser.window_handles:
-            while self.warning_element() is False:
-                time.sleep(0.1)
-
     def deadline_passed(self, now, deadline):
         return (datetime.now() - now).seconds > deadline
 
